==> iTop-3.1.0-2-11973.zip: web/datamodels/2.x/itop-attachments/dictionaries/cs.dict.itop-attachments.php <==
<?php
// Copyright (C) 2010-2023 Combodo SARL
//
//   This file is part of iTop.
//
//   iTop is free software; you can redistribute it and/or modify
//   it under the terms of the GNU Affero General Public License as published by
//   the Free Software Foundation, either version 3 of the License, or
//   (at your option) any later version.
//
//   iTop is distributed in the hope that it will be useful,
//   but WITHOUT ANY WARRANTY; without even the implied warranty of
//   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//   GNU Affero General Public License for more details.
//
//   You should have received a copy of the GNU Affero General Public License
//   along with iTop. If not, see <http://www.gnu.org/licenses/>
/**
 * Localized data.
 *
 * @author      Lukáš Dvořák <lukas.dvorak@itopportal.cz>
 * @author      Daniel Rokos <daniel.rokos@itopportal.cz>
 * @copyright   Copyright (C) 2010-2023 Combodo SARL
 * @license     http://opensource.org/licenses/AGPL-3.0
 */
Dict::Add('CS CZ', 'Czech', 'Čeština', array(
	'Attachments:TabTitle_Count' => 'Přílohy (%1$d)',
	'Attachments:EmptyTabTitle' => 'Přílohy',
	'Attachments:FieldsetTitle' => 'Přílohy',
	'Attachments:DeleteBtn' => 'Odstranit',
	'Attachments:History_File_Added' => 'Příloha %1$s byla přidána.',
	'Attachments:History_File_Removed' => 'Příloha %1$s byla odstraněna.',
	'Attachments:AddAttachment' => 'Přidat přílohu: ',
	'Attachments:UploadNotAllowedOnThisSystem' => 'Na tomto systému není povoleno nahrávání souborů.',
	'Attachment:Max_Go' => '(Maximální velikost souboru: %1$s GiB)',
	'Attachment:Max_Mo' => '(Maximální velikost souboru: %1$s MiB)',
	'Attachment:Max_Ko' => '(Maximální velikost souboru: %1$s KiB)',
	'Attachments:NoAttachment' => 'Žádná příloha. ',
	'Attachments:PreviewNotAvailable' => 'Pro tento typ přílohy není náhled k dispozici.',
	'Attachments:Error:FileTooLarge' => 'File is too large to be uploaded. %1$s~~',
	'Attachments:Error:UploadedFileEmpty' => 'The received file is empty and cannot be attached.
Either you have pushed an empty file,
or ask your '.ITOP_APPLICATION_SHORT.' administrator if the '.ITOP_APPLICATION_SHORT.' server disk is full.~~',
	'Attachments:Render:Icons' => 'Display as icons~~',
	'Attachments:Render:Table' => 'Display as list~~',
	'UI:Attachments:DropYourFileHint' => 'Drop files anywhere in this area~~',
));

//
// Class: Attachment
//

Dict::Add('CS CZ', 'Czech', 'Čeština', array(
	'Class:Attachment' => 'Attachment~~',
	'Class:Attachment+' => '~~',
	'Class:Attachment/Attribute:expire' => 'Expire~~',
	'Class:Attachment/Attribute:expire+' => '~~',
	'Class:Attachment/Attribute:temp_id' => 'Temporary id~~',
	'Class:Attachment/Attribute:temp_id+' => '~~',
	'Class:Attachment/Attribute:item_class' => 'Item class~~',
	'Class:Attachment/Attribute:item_class+' => '~~',
	'Class:Attachment/Attribute:item_id' => 'Item~~',
	'Class:Attachment/Attribute:item_id+' => '~~',
	'Class:Attachment/Attribute:item_org_id' => 'Item organization~~',
	'Class:Attachment/Attribute:item_org_id+' => '~~',
	'Class:Attachment/Attribute:contents' => 'Contents~~',
	'Class:Attachment/Attribute:contents+' => '~~',
));


Dict::Add('CS CZ', 'Czech', 'Čeština', array(
	'Attachments:File:Thumbnail' => 'Icon~~',
	'Attachments:File:Name' => 'File name~~',
	'Attachments:File:Date' => 'Upload date~~',
	'Attachments:File:Uploader' => 'Uploaded by~~',
	'Attachments:File:Size' => 'Size~~',
	'Attachments:File:MimeType' => 'Type~~',
	'Attachments:File:DownloadsCount' => 'Downloads~~',
));
//
// Class: Attachment
//

Dict::Add('CS CZ', 'Czech', 'Čeština', array(
	'Class:Attachment/Attribute:creation_date' => 'Creation date~~',
	'Class:Attachment/Attribute:creation_date+' => '~~',
	'Class:Attachment/Attribute:user_id' => 'User id~~',
	'Class:Attachment/Attribute:user_id+' => '~~',
	'Class:Attachment/Attribute:contact_id' => 'Contact id~~',
	'Class:Attachment/Attribute:contact_id+' => '~~',
));

//
// Class: TriggerOnAttachmentDownload
//

Dict::Add('CS CZ', 'Czech', 'Čeština', array(
	'Class:TriggerOnAttachmentDownload' => 'Trigger (on object\'s attachment download)~~',
	'Class:TriggerOnAttachmentDownload+' => 'Trigger on object\'s attachment download of [a child class of] the given class~~',
));

==> iTop-3.2.0-2-14758.zip: web/datamodels/2.x/itop-attachments/dictionaries/cs.dict.itop-attachments.php <==
<?php
/**
 * Localized data
 *
 * @copyright Copyright (C) 2010-2024 Combodo SAS
 * @license    https://opensource.org/licenses/AGPL-3.0
 * 
 */
/**
 * @author Lukáš Dvořák <lukas.dvorak@itopportal.cz>
 * @author Daniel Rokos <daniel.rokos@itopportal.cz>
 *
 */
Dict::Add('CS CZ', 'Czech', 'Čeština', [
	'Attachment:Max_Go' => '(Maximální velikost souboru: %1$s GiB)',
	'Attachment:Max_Ko' => '(Maximální velikost souboru: %1$s KiB)',
	'Attachment:Max_Mo' => '(Maximální velikost souboru: %1$s MiB)',
	'Attachments:AddAttachment' => 'Přidat přílohu: ',
	'Attachments:DeleteBtn' => 'Odstranit',
	'Attachments:EmptyTabTitle' => 'Přílohy',
	'Attachments:Error:FileTooLarge' => 'File is too large to be uploaded. %1$s~~',
	'Attachments:Error:UploadedFileEmpty' => 'The received file is empty and cannot be attached.
Either you have pushed an empty file,
or ask your '.ITOP_APPLICATION_SHORT.' administrator if the '.ITOP_APPLICATION_SHORT.' server disk is full.~~',
	'Attachments:FieldsetTitle' => 'Přílohy',
	'Attachments:File:Date' => 'Upload date~~',
	'Attachments:File:DownloadsCount' => 'Downloads~~',
	'Attachments:File:MimeType' => 'Type~~',
	'Attachments:File:Name' => 'File name~~',
	'Attachments:File:Size' => 'Size~~',
	'Attachments:File:Thumbnail' => 'Icon~~',
	'Attachments:File:Uploader' => 'Uploaded by~~',
	'Attachments:History_File_Added' => 'Příloha %1$s byla přidána.',
	'Attachments:History_File_Removed' => 'Příloha %1$s byla odstraněna.',
	'Attachments:NoAttachment' => 'Žádná příloha. ',
	'Attachments:PreviewNotAvailable' => 'Pro tento typ přílohy není náhled k dispozici.',
	'Attachments:Render:Icons' => 'Display as icons~~',
	'Attachments:Render:Table' => 'Display as list~~',
	'Attachments:TabTitle_Count' => 'Přílohy (%1$d)',
	'Attachments:UploadNotAllowedOnThisSystem' => 'Na tomto systému není povoleno nahrávání souborů.',
	'Class:Attachment' => 'Attachment~~',
	'Class:Attachment+' => '~~',
	'Class:Attachment/Attribute:contact_id' => 'Contact id~~',
	'Class:Attachment/Attribute:contact_id+' => '~~',
	'Class:Attachment/Attribute:contents' => 'Contents~~',
	'Class:Attachment/Attribute:contents+' => '~~',
	'Class:Attachment/Attribute:creation_date' => 'Creation date~~',
	'Class:Attachment/Attribute:creation_date+' => '~~',
	'Class:Attachment/Attribute:expire' => 'Expire~~',
	'Class:Attachment/Attribute:expire+' => '~~',
	'Class:Attachment/Attribute:item_class' => 'Item class~~',
	'Class:Attachment/Attribute:item_class+' => '~~',
	'Class:Attachment/Attribute:item_id' => 'Item~~',
	'Class:Attachment/Attribute:item_id+' => '~~',
	'Class:Attachment/Attribute:item_org_id' => 'Item organization~~',
	'Class:Attachment/Attribute:item_org_id+' => '~~',
	'Class:Attachment/Attribute:temp_id' => 'Temporary id~~',
	'Class:Attachment/Attribute:temp_id+' => '~~',
	'Class:Attachment/Attribute:user_id' => 'User id~~',
	'Class:Attachment/Attribute:user_id+' => '~~',
	'Class:TriggerOnAttachmentDownload' => 'Trigger (on object\'s attachment download)~~',
	'Class:TriggerOnAttachmentDownload+' => 'Trigger on object\'s attachment download of [a child class of] the given class~~',
	'UI:Attachments:DropYourFileHint' => 'Drop files anywhere in this area~~',
]);
